@@ -3,6 +3,8 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
+our $VERSION = '0.02';
+
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
 use constant like_debian => (linuxdistro => '~debian');
@@ -23,7 +25,8 @@ sub mapping {
      [cpanmod => 'Alien::ffmpeg',
       [os_freebsd,
        [package => 'yasm']],
-      # XXX what about debian?
+      [like_debian,
+       [package => 'yasm']],
      ],
 
      [cpanmod => 'Alien::FFTW3',
@@ -35,7 +38,9 @@ sub mapping {
      [cpanmod => 'Alien::HDF4',
       [os_freebsd,
        [package => 'hdf']],
-      # XXX what about debian?
+      [like_debian,
+       # "yasm/nasm not found or too old. Use --disable-yasm for a crippled build."
+       [package => 'yasm']],
      ],
 
      [cpanmod => 'Alien::LibUSBx',
@@ -90,6 +95,9 @@ sub mapping {
       # XXX what about debian?
      ],
 
+     [cpanmod => 'Alien::uPB',
+      [package => 'unzip']],
+
      [cpanmod => 'Alien::wxWidgets',
       [like_debian,
        [package => 'libgtk2.0-dev']],
@@ -301,7 +309,7 @@ sub mapping {
 
      [cpanmod => 'Curses::UI::Mousehandler::GPM',
       [like_debian,
-       [package => 'libgpm-dev']]],
+       [package => 'libgpm-dev', 'libncursesw5-dev']]],
 
      [cpanmod => 'Database::Cassandra::Client',
       [os_freebsd,
@@ -376,7 +384,7 @@ sub mapping {
      [cpanmod => 'Device::Velleman::K8055::libk8055',
       [os_freebsd,
        [package => 'libk8055']],
-      # XXX what about debian?
+      # not available on debian
      ],
 
      [cpanmod => 'DLM::Client',
@@ -400,8 +408,9 @@ sub mapping {
       [os_freebsd,
        # build is not successful anyway (Evas.h cannot be found), additionally the prereqs install also gcc on a freebsd10 system
        [package => ['evas-core', 'elementary']]],
-      # what about debian?
-     ],
+      [like_debian,
+       # here too: build is not successful anyway (Evas.h cannot be found)
+       [package => ['libevas-dev', 'libelementary-dev']]]],
 
      [cpanmod => 'EV::ADNS',
       [os_freebsd,
@@ -549,7 +558,10 @@ sub mapping {
       [package => 'gnuplot']],
 
      [cpanmod => 'Graphics::Plotter',
-      [package => 'plotutils']],
+      [os_freebsd,
+       [package => 'plotutils']],
+      [like_debian,
+       [package => 'libplot-dev']]],
 
      [cpanmod => ['Graphics::SANE', 'Sane'],
       [os_freebsd,
@@ -659,21 +671,18 @@ sub mapping {
        ]],
 
      [cpanmod => 'Image::Ocrad',
-      [os_freebsd,
-       [package => 'ocrad']],
-      # XXX what about debian?
-     ],
+      [package => 'ocrad']],
 
      [cpanmod => 'Image::Resize::OpenCV',
       [os_freebsd,
        [package => 'opencv']],
       [like_debian,
-       [package => 'libcv-dev']]],
+       [package => ['libcv-dev', 'libhighgui-dev']]]],
 
      [cpanmod => 'Image::SubImageFind',
       # XXX what about freebsd?
       [like_debian,
-       [package => 'libmagick++-dev']]],
+       [package => ['libmagick++-dev', 'graphicsmagick-libmagick-dev-compat']]]],
 
      [cpanmod => 'Imager',
       [os_freebsd,
@@ -708,8 +717,8 @@ sub mapping {
       [os_freebsd,
        # does not work, see https://rt.cpan.org/Ticket/Display.html?id=93690
        [package => 'lua']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'liblua5.1-0-dev']]],
 
      [cpanmod => 'Inline::Python',
       [os_freebsd,
@@ -1204,10 +1213,8 @@ sub mapping {
       [os_freebsd,
        [package => 'libvterm']],
       [like_debian,
-       [linuxdistrocodename => ['squeeze', 'wheezy'],
+       [linuxdistrocodename => ['squeeze', 'wheezy', 'jessie'],
 	[package => []]],
-       # currently (2015-10) only available in experimental
-       # (which is included in my jessie&sid VMs)
        [package => 'libvterm-dev']]],
 
      [cpanmod => 'Text::Aspell',
@@ -1229,8 +1236,8 @@ sub mapping {
      [cpanmod => 'Text::CSV::LibCSV',
       [os_freebsd,
        [package => 'libcsv']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'libcsv-dev']]],
 
      [cpanmod => 'Text::Hunspell',
       [os_freebsd,
@@ -1248,8 +1255,8 @@ sub mapping {
      [cpanmod => 'Text::Migemo',
       [os_freebsd,
        [package => 'ja-migemo']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'libmigemo-dev']]],
 
      [cpanmod => 'Text::VimColor',
       [package => 'vim']],
@@ -1298,13 +1305,15 @@ sub mapping {
      ],
 
      [cpanmod => 'Video::FFmpeg',
-      [package => 'ffmpeg']],
+      [package => 'ffmpeg']], # on Debian only found in backports or www.deb-multimedia.org; still does not build because avformat.h is not available
 
      [cpanmod => 'WWW::Bootstrap',
       [os_freebsd,
        [package => 'npm']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy)],
+	[package => []]],
+       [package => 'npm']]],
 
      [cpanmod => 'WWW::Mechanize::PhantomJS',
       [os_freebsd,
@@ -1321,9 +1330,8 @@ sub mapping {
      [cpanmod => 'XML::LibXSLT',
       [os_freebsd,
        [package => 'libxslt']],
-      # XXX check: gdbm needed for XML::LibXSLT in debian?!
       [like_debian,
-       [package => 'libxslt1-dev']],
+       [package => ['libxslt1-dev', 'libgdbm-dev']]],
       [linuxdistro => '~fedora',
        [package => 'libxslt-devel']]],
 
@@ -1337,7 +1345,7 @@ sub mapping {
       # compiles only with perl < 5.14, see https://rt.cpan.org/Ticket/Display.html?id=66849
       [os_freebsd,
        [package => 'Sablot']],
-      # XXX what about debian?
+      # no sablot package on debian
      ],
 
      [cpanmod => 'XML::Saxon::XSLT2', # needs java
@@ -1357,13 +1365,16 @@ sub mapping {
        [package => 'xerces-c2']],
       [like_debian,
        # probably needs setting of XERCES_* variables?
-       [package => 'libxerces-c2-dev']]],
+       [linuxdistrocodename => ['wheezy'],
+	[package => 'libxerces-c2-dev']],
+       [package => 'libxerces-c-dev'], # will not work, because jessie has Xerces-C-3.1.1
+      ]],
 
      [cpanmod => 'X::Osd',
       [os_freebsd,
        [package => 'xosd']],
-      # XXX what about debian?
-     ],
+      [like_debian,
+       [package => 'libxosd-dev']]],
 
      [cpanmod => 'X11::GUITest',
       [like_debian,
@@ -1375,14 +1386,23 @@ sub mapping {
       [os_freebsd,
        [package => 'xcb-util-wm']],
       [like_debian,
-       [package => ['xsltproc', 'libxcb-util0-dev', 'libxcb-xinerama0-dev', 'libxcb-icccm4-dev']]]],
+       [package => ['xsltproc', 'xcb-proto', 'libxcb-util0-dev', 'libxcb-xinerama0-dev', 'libxcb-icccm4-dev']]]],
 
-     [cpanmod => ['ZMQ::LibZMQ4', 'ZMQ::FFI'],
+     [cpanmod => 'ZMQ::FFI',
       [os_freebsd,
        [package => 'libzmq4']], # seems to hang with nonthreaded perls on freebsd, wait-and-kill rule exists
       [like_debian,
        [package => 'libzmq-dev']]],
 
+     [cpanmod => 'ZMQ::LibZMQ4',
+      [os_freebsd,
+       [package => 'libzmq4']], # seems to hang with nonthreaded perls on freebsd, wait-and-kill rule exists (?)
+      [like_debian,
+#       [linuxdistrocodename => [qw(squeeze wheezy jessie)],
+#	[package => []]], # libzmq5 is ZMQ4.1 (!); according to http://zeromq.org/distro:debian only available in experimental (and probably sid)
+       [package => 'libzmq3-dev'], # note: libzmq3-dev is ZMQ4.0 (!)
+      ]],
+
      [cpanmod => 'ZOOM::IRSpy',
       [os_freebsd,
        [package => 'yaz']],
